@@ -32,6 +32,7 @@ from .deprecation import DeprecationClient
 from .enrich import EnrichClient
 from .eql import EqlClient
 from .features import FeaturesClient
+from .fleet import FleetClient
 from .graph import GraphClient
 from .ilm import IlmClient
 from .indices import IndicesClient
@@ -46,6 +47,7 @@ from .remote import RemoteClient
 from .rollup import RollupClient
 from .searchable_snapshots import SearchableSnapshotsClient
 from .security import SecurityClient
+from .shutdown import ShutdownClient
 from .slm import SlmClient
 from .snapshot import SnapshotClient
 from .sql import SqlClient
@@ -55,6 +57,8 @@ from .text_structure import TextStructureClient
 from .transform import TransformClient
 from .utils import SKIP_IN_PATH, _bulk_body, _make_path, _normalize_hosts, query_params
 from .watcher import WatcherClient
+
+# xpack APIs
 from .xpack import XPackClient
 
 logger = logging.getLogger("elasticsearch")
@@ -208,7 +212,6 @@ class AsyncElasticsearch(object):
         self.cat = CatClient(self)
         self.cluster = ClusterClient(self)
         self.dangling_indices = DanglingIndicesClient(self)
-        self.features = FeaturesClient(self)
         self.indices = IndicesClient(self)
         self.ingest = IngestClient(self)
         self.nodes = NodesClient(self)
@@ -222,6 +225,8 @@ class AsyncElasticsearch(object):
         self.deprecation = DeprecationClient(self)
         self.enrich = EnrichClient(self)
         self.eql = EqlClient(self)
+        self.features = FeaturesClient(self)
+        self.fleet = FleetClient(self)
         self.graph = GraphClient(self)
         self.ilm = IlmClient(self)
         self.license = LicenseClient(self)
@@ -233,6 +238,7 @@ class AsyncElasticsearch(object):
         self.searchable_snapshots = SearchableSnapshotsClient(self)
         self.security = SecurityClient(self)
         self.slm = SlmClient(self)
+        self.shutdown = ShutdownClient(self)
         self.sql = SqlClient(self)
         self.ssl = SslClient(self)
         self.text_structure = TextStructureClient(self)
@@ -269,7 +275,7 @@ class AsyncElasticsearch(object):
         """
         Returns whether the cluster is running.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/index.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/index.html>`_
         """
         try:
             return await self.transport.perform_request(
@@ -283,7 +289,7 @@ class AsyncElasticsearch(object):
         """
         Returns basic information about the cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/index.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/index.html>`_
         """
         return await self.transport.perform_request(
             "GET", "/", params=params, headers=headers
@@ -303,7 +309,7 @@ class AsyncElasticsearch(object):
         Creates a new document in the index.  Returns a 409 response when a document
         with a same ID already exists in the index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-index_.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/docs-index_.html>`_
 
         :arg index: The name of the index
         :arg id: Document ID
@@ -358,7 +364,7 @@ class AsyncElasticsearch(object):
         """
         Creates or updates a document in an index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-index_.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/docs-index_.html>`_
 
         :arg index: The name of the index
         :arg body: The document
@@ -422,7 +428,7 @@ class AsyncElasticsearch(object):
         """
         Allows to perform multiple index/update/delete operations in a single request.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-bulk.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/docs-bulk.html>`_
 
         :arg body: The operation definition and data (action-data
             pairs), separated by newlines
@@ -469,7 +475,7 @@ class AsyncElasticsearch(object):
         """
         Explicitly clears the search context for a scroll.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/clear-scroll-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/clear-scroll-api.html>`_
 
         :arg body: A comma-separated list of scroll IDs to clear if none
             was specified via the scroll_id parameter
@@ -508,7 +514,7 @@ class AsyncElasticsearch(object):
         """
         Returns number of documents matching a query.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-count.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/search-count.html>`_
 
         :arg body: A query to restrict the results specified with the
             Query DSL (optional)
@@ -566,7 +572,7 @@ class AsyncElasticsearch(object):
         """
         Removes a document from the index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-delete.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/docs-delete.html>`_
 
         :arg index: The name of the index
         :arg id: The document ID
@@ -644,7 +650,7 @@ class AsyncElasticsearch(object):
         """
         Deletes documents matching the provided query.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-delete-by-query.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/docs-delete-by-query.html>`_
 
         :arg index: A comma-separated list of index names to search; use
             `_all` or empty string to perform the operation on all indices
@@ -741,7 +747,7 @@ class AsyncElasticsearch(object):
         Changes the number of requests per second for a particular Delete By Query
         operation.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-delete-by-query.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/docs-delete-by-query.html>`_
 
         :arg task_id: The task id to rethrottle
         :arg requests_per_second: The throttle to set on this request in
@@ -762,7 +768,7 @@ class AsyncElasticsearch(object):
         """
         Deletes a script.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/modules-scripting.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/modules-scripting.html>`_
 
         :arg id: Script ID
         :arg master_timeout: Specify timeout for connection to master
@@ -791,7 +797,7 @@ class AsyncElasticsearch(object):
         """
         Returns information about whether a document exists in an index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-get.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/docs-get.html>`_
 
         :arg index: The name of the index
         :arg id: The document ID
@@ -842,7 +848,7 @@ class AsyncElasticsearch(object):
         """
         Returns information about whether a document source exists in an index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-get.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/docs-get.html>`_
 
         :arg index: The name of the index
         :arg id: The document ID
@@ -898,7 +904,7 @@ class AsyncElasticsearch(object):
         """
         Returns information about why a specific matches (or doesn't match) a query.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-explain.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/search-explain.html>`_
 
         :arg index: The name of the index
         :arg id: The document ID
@@ -951,7 +957,7 @@ class AsyncElasticsearch(object):
         Returns the information about the capabilities of fields among multiple
         indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-field-caps.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/search-field-caps.html>`_
 
         :arg body: An index filter specified with the Query DSL
         :arg index: A comma-separated list of index names; use `_all` or
@@ -992,7 +998,7 @@ class AsyncElasticsearch(object):
         """
         Returns a document.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-get.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/docs-get.html>`_
 
         :arg index: The name of the index
         :arg id: The document ID
@@ -1033,7 +1039,7 @@ class AsyncElasticsearch(object):
         """
         Returns a script.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/modules-scripting.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/modules-scripting.html>`_
 
         :arg id: Script ID
         :arg master_timeout: Specify timeout for connection to master
@@ -1060,7 +1066,7 @@ class AsyncElasticsearch(object):
         """
         Returns the source of a document.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-get.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/docs-get.html>`_
 
         :arg index: The name of the index
         :arg id: The document ID
@@ -1110,7 +1116,7 @@ class AsyncElasticsearch(object):
         """
         Allows to get multiple documents in one request.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-multi-get.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/docs-multi-get.html>`_
 
         :arg body: Document identifiers; can be either `docs`
             (containing full document information) or `ids` (when index and type is
@@ -1157,7 +1163,7 @@ class AsyncElasticsearch(object):
         """
         Allows to execute several search operations in one request.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-multi-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/search-multi-search.html>`_
 
         :arg body: The request definitions (metadata-search request
             definition pairs), separated by newlines
@@ -1214,7 +1220,7 @@ class AsyncElasticsearch(object):
         """
         Allows to execute several search template operations in one request.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-multi-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/search-multi-search.html>`_
 
         :arg body: The request definitions (metadata-search request
             definition pairs), separated by newlines
@@ -1267,7 +1273,7 @@ class AsyncElasticsearch(object):
         """
         Returns multiple termvectors in one request.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-multi-termvectors.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/docs-multi-termvectors.html>`_
 
         :arg body: Define ids, documents, parameters or a list of
             parameters per document here. You must at least provide a list of
@@ -1320,7 +1326,7 @@ class AsyncElasticsearch(object):
         """
         Creates or updates a script.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/modules-scripting.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/modules-scripting.html>`_
 
         :arg id: Script ID
         :arg body: The document
@@ -1348,7 +1354,7 @@ class AsyncElasticsearch(object):
         Allows to evaluate the quality of ranked search results over a set of typical
         search queries
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-rank-eval.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/search-rank-eval.html>`_
 
         .. warning::
 
@@ -1397,7 +1403,7 @@ class AsyncElasticsearch(object):
         source documents by a query, changing the destination index settings, or
         fetching the documents from a remote cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-reindex.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/docs-reindex.html>`_
 
         :arg body: The search definition using the Query DSL and the
             prototype for the index request.
@@ -1433,7 +1439,7 @@ class AsyncElasticsearch(object):
         """
         Changes the number of requests per second for a particular Reindex operation.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-reindex.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/docs-reindex.html>`_
 
         :arg task_id: The task id to rethrottle
         :arg requests_per_second: The throttle to set on this request in
@@ -1456,7 +1462,7 @@ class AsyncElasticsearch(object):
         """
         Allows to use the Mustache language to pre-render a search definition.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-template.html#_validating_templates>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/search-template.html#_validating_templates>`_
 
         :arg body: The search definition template and its params
         :arg id: The id of the stored search template
@@ -1496,7 +1502,7 @@ class AsyncElasticsearch(object):
         """
         Allows to retrieve a large numbers of results from a single search request.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-request-body.html#request-body-search-scroll>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/search-request-body.html#request-body-search-scroll>`_
 
         :arg body: The scroll ID if not passed by URL or query
             parameter.
@@ -1568,7 +1574,7 @@ class AsyncElasticsearch(object):
         """
         Returns results matching a query.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/search-search.html>`_
 
         :arg body: The search definition using the Query DSL
         :arg index: A comma-separated list of index names to search; use
@@ -1694,7 +1700,7 @@ class AsyncElasticsearch(object):
         Returns information about the indices and shards that a search request would be
         executed against.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-shards.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/search-shards.html>`_
 
         :arg index: A comma-separated list of index names to search; use
             `_all` or empty string to perform the operation on all indices
@@ -1737,7 +1743,7 @@ class AsyncElasticsearch(object):
         """
         Allows to use the Mustache language to pre-render a search definition.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/search-template.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/search-template.html>`_
 
         :arg body: The search definition template and its params
         :arg index: A comma-separated list of index names to search; use
@@ -1804,7 +1810,7 @@ class AsyncElasticsearch(object):
         Returns information and statistics about terms in the fields of a particular
         document.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-termvectors.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/docs-termvectors.html>`_
 
         :arg index: The index in which the document resides.
         :arg body: Define parameters and or supply a document to get
@@ -1863,7 +1869,7 @@ class AsyncElasticsearch(object):
         """
         Updates a document with a script or partial document.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-update.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/docs-update.html>`_
 
         :arg index: The name of the index
         :arg id: Document ID
@@ -1956,7 +1962,7 @@ class AsyncElasticsearch(object):
         Performs an update on every document in the index without changing the source,
         for example to pick up a mapping change.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-update-by-query.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/docs-update-by-query.html>`_
 
         :arg index: A comma-separated list of index names to search; use
             `_all` or empty string to perform the operation on all indices
@@ -2056,7 +2062,7 @@ class AsyncElasticsearch(object):
         Changes the number of requests per second for a particular Update By Query
         operation.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/docs-update-by-query.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/docs-update-by-query.html>`_
 
         :arg task_id: The task id to rethrottle
         :arg requests_per_second: The throttle to set on this request in
@@ -2093,7 +2099,7 @@ class AsyncElasticsearch(object):
         """
         Returns available script types, languages and contexts
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/modules-scripting.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/modules-scripting.html>`_
 
         .. warning::
 
@@ -2109,7 +2115,7 @@ class AsyncElasticsearch(object):
         """
         Close a point in time
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/point-in-time-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/point-in-time-api.html>`_
 
         :arg body: a point-in-time id to close
         """
@@ -2124,7 +2130,7 @@ class AsyncElasticsearch(object):
         """
         Open a point in time that can be used in subsequent searches
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/point-in-time-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/point-in-time-api.html>`_
 
         :arg index: A comma-separated list of index names to open point
             in time; use `_all` or empty string to perform the operation on all
